module Sync_Gen (
    Hsync,     //H-Sync
    Vsync,     //V-Sync
    Hcount,    //Horizontal Position
    Vcount,    //Vertical Position
    Disp,      //Display Area
    Clk,       //Syaten Clock
    xReset );  //Global Reset
    
    parameter H_Total_Dots  = 1039 ; 
    parameter H_Dots        = 800 ;
    parameter H_Sync_Start  = 856 ;
    parameter H_Sync_End    = 976 ;

    parameter V_Total_Lines =  665 ;
    parameter V_Lines       = 600 ;
    parameter V_Sync_Start  =  637 ;
    parameter V_Sync_End    =  643 ;

    parameter Sync_Polarity =    1 ;
    
    output         Hsync;
    output         Vsync ;
    output  [11:0] Hcount ;
    output   [9:0] Vcount ;
    output         Disp ;
    input          Clk;
    input          xReset;
    
    reg            Hsync_i;
    reg     [11:0] Hcount_i ;
    reg      [9:0] Vcount_i ;
    reg            Hsync;
    reg            Vsync ;
    reg     [11:0] Hcount ;
    reg      [9:0] Vcount ;
    reg            Disp ;
    
    always @( posedge Clk or negedge xReset )
    begin
        if( !xReset )begin
            Hcount_i <= 0; Vcount_i <= 0;
            Hsync_i  <= 0;
            Hcount   <= 0; Vcount   <= 0;
            Hsync    <= 0; Vsync    <= 0;
            Disp <= 0 ;
        end else begin
            Hcount_i <= ( Hcount_i == H_Total_Dots )? 0 : Hcount_i + 1 ;
            Vcount_i <= ( Hcount_i != H_Total_Dots )? Vcount_i : 
                           ( Vcount_i == V_Total_Lines )? 0 : Vcount_i + 1  ;          
            Hsync_i  <= ( Hcount_i == H_Sync_Start )? Sync_Polarity :
                            ( Hcount_i == H_Sync_End )? ~Sync_Polarity : Hsync_i ;
            Vsync  <= ( Vcount_i == V_Sync_Start )? Sync_Polarity :
                            ( Vcount_i == V_Sync_End )? ~Sync_Polarity : Vsync ;
            Disp     <= ( Hcount_i < H_Dots ) & (Vcount_i < V_Lines );
            Hcount   <= Hcount_i ;
            Vcount   <= Vcount_i ; 
            Hsync    <= Hsync_i ;
        end
    end
endmodule            
