module NTSC_enc( R, G, B, CompOut, Hcount, Vcount, Odd, Clk, xReset ) ;
    input           [7:0] R, G, B ;
    output          [7:0] CompOut ;
    output         [10:0] Hcount ;
    output          [9:0] Vcount ;
    output                Odd ;
    
    input                 Clk ;
    input                 xReset ;
    
    wire                  Csync ;
    wire                  BE ;
    wire           [10:0] Hcount ;
    wire            [9:0] Vcount ;
    wire                  Odd ;
    wire            [2:0] CS ;
    wire signed    [10:0] Sin ;
    wire signed    [10:0] Cos ;
    wire signed    [10:0] Y, C ;
    wire            [7:0] CompOut ;
    
    Sync_Gen Sync_Gen (
                 .Hsync(),        //H-Sync
                 .Vsync(),        //V-Sync
                 .Csync(Csync),   //Composit Sync
                 .Hcount(Hcount), //Horizontal Position
                 .Vcount(Vcount), //Vertical Position
                 .BE(BE),           //Burst Enable
                 .CS(CS),
                 .Odd(Odd),       //Odd field
                 .Clk(Clk),       //Syaten Clock
                 .xReset(xReset) );  //Global Reset
                 
    IQOsc   IQOsc (
                 .CS(CS),        //Phase of color Sub 
                 .Cos(Cos),       //Q
                 .Sin(Sin),       //I
                 .Clk(Clk),       //Syaten Clock
                 .xReset(xReset) );  //Global Reset
                 
    Matrix  Matrix( 
                .R(R),
                .G(G),
                .B(B),
                .Sin(Sin),
                .Cos(Cos),
                .Y(Y),
                .C(C),
                .Clk(Clk),
                .xReset(xReset) ) ; 
    Mixer   Mixer(
                .Y(Y),
                .C(C),
                .Csync(Csync),
                .BE(BE),
                .CS(CS),
                .Comp(CompOut),
                .CLK(Clk),
                .xReset(xReset)
                );

endmodule
            