//NTSC Sync-gen Clk is 8Fs (4.5/286*455/2*8)
module Sync_Gen (
    Hsync,     //H-Sync
    Vsync,     //V-Sync
    Csync,     //Composit Sync
    Hcount,    //Horizontal Position
    Vcount,    //Vertical Position
    BE,        //Burst Enable
    CS,        //Color Sub Phase
    Odd,       //Odd field

    Clk,       //Syaten Clock
    xReset );  //Global Reset
 
    output         Hsync;
    output         Vsync ;
    output         Csync ;
    output  [10:0] Hcount ;
    output   [9:0] Vcount ;

    output         BE ;
    output   [2:0] CS ;
    output         Odd ;
    
    input          Clk;
    input          xReset;
    

    reg            Hsync;
    reg            Vsync;
    reg            Csync ;
    reg     [10:0] Hcount ;
    reg      [9:0] Vcount ;
    reg            BE ;
    reg      [2:0] CS ;
    reg            Odd ;

    reg            Hsync_i;
    reg            Vsync_i ;
    reg            HatVs_i;
    reg            HatVeq_i;
    reg     [10:0] Hcount_i ;
    reg      [9:0] Vcount_i ;
    reg     [10:0] Hcount_i2 ;
    reg      [9:0] Vcount_i2 ;    
    reg            BE_i ;
    reg      [2:0] CS_i ;
    wire           Vs_i ;
    wire           Ve_i ;
    wire           Vh_i ;
    wire           Csync_i ;

    assign         Vs_i = ( Vcount_i2 >= 6 ) & ( Vcount_i2 < 12 ) ;
    assign         Ve_i = ( Vcount_i2 < 6 ) 
                        | ( Vcount_i2 >= 12 ) & ( Vcount_i2 < 18 ) ;
    assign         Vh_i = ~( Vs_i | Ve_i ) ;
                     
    assign         Csync_i = ( Vs_i & HatVs_i )
                            | ( Ve_i & HatVeq_i )
                            | ( Vh_i & Hsync_i ) ;

    always @( posedge Clk or negedge xReset )
    begin
        if( !xReset )begin
            Hcount_i  <= 0; 
            Hcount_i2 <= 0; 
            Hsync_i   <= 0;
            HatVs_i   <= 0;
            HatVeq_i  <= 0;
            BE_i      <= 0;
            
            Hcount   <= 0; Hcount_i <= 0 ; Hcount_i2 <= 0 ;
            Vcount   <= 0; Vcount_i <= 0 ; Vcount_i2 <= 0 ;

            Hsync    <= 0; Vsync    <= 0;
            CS       <= 0 ;
            BE       <= 0 ;
            Odd      <= 0 ;
            
        end else begin
            Hcount_i  <= ( Hcount_i    == 1819 )? 0 : Hcount_i  + 1 ;
            Hcount_i2 <= ( Hcount_i2   ==  909 )? 0 : Hcount_i2 + 1 ;
            Hsync_i   <= ( Hcount_i    ==    0 )? 0 :
                            ( Hcount_i ==  136 )? 1 : Hsync_i ;
            HatVeq_i  <= ( Hcount_i2   ==    0 )? 0  : 
                           ( Hcount_i2 ==   68 )? 1 : HatVeq_i  ;  
            HatVs_i   <= ( Hcount_i2   ==    0 )? 0  : 
                           ( Hcount_i2 ==  774 )? 1 : HatVs_i  ;  
            BE_i      <= ( Hcount_i    ==  152 )? 1 :
                            ( Hcount_i ==  224 )? 0 : BE_i ;
            CS        <= CS + 1 ;
                     
            Vcount_i  <= ( Hcount_i  != 1819   )? Vcount_i  : 
                           ( Vcount_i  == 524 )? 0 : Vcount_i  + 1  ;  
            Vcount_i2 <= ( Hcount_i2 != 909 )? Vcount_i2 : 
                           ( Vcount_i2 == 524 )? 0 : Vcount_i2 + 1  ;
            Vsync_i   <= ~( Vs_i | Ve_i ) ;
            Odd       <= ( ( Hcount_i2 == 909 )&( Vcount_i2 == 524 ) )? ~Odd : Odd ;
                  
            Hsync  <= ~Hsync_i ;
            Vsync  <= Vsync_i ;
            Csync  <= Csync_i ;
            Vcount <= Vcount_i ;
            Hcount <= Hcount_i ;
            BE     <= BE_i & Vh_i ;
        end
    end
endmodule            
