module Led7Seg  (
                    Din,       //Input 4Bit data
                    Hcount,    //H-Position
                    Vcount,    //V-Position
                    R,         //
                    G,         //
                    B,         //
                    Clk,       //Syaten Clock
                    xReset );  //Global Reset
    
    parameter       OrgX  =  220 ;
    parameter       OrgY  =   30 ;
    parameter       Size  =   60 ;
    parameter       BarFg = 3'b111 ;
    parameter       BarBg = 3'b000 ;
    
    input     [3:0] Din ;
    input    [10:0] Hcount ;
    input     [9:0] Vcount ;
    output          R ;
    output          G ;
    output          B ;
    
    input           Clk ;
    input           xReset ;
    
    wire            Hsync ;
    wire            Vsync ;
    wire            Sa, Sb, Sc, Sd, Se, Sf, Sg ;
    wire            Ra, Rb, Rc, Rd, Re, Rf, Rg ;
    wire            Ga, Gb, Gc, Gd, Ge, Gf, Gg ;
    wire            Ba, Bb, Bc, Bd, Be, Bf, Bg ;
     
    reg             R, G, B ;
    
    Bar3  #( OrgX+Size,
             OrgX+Size*5,
             OrgY,
             OrgY+Size,
             BarFg,
             BarBg)
          SegA        ( .SW(Sa),
                        .Hcount(Hcount),    //Horizontal Position
                        .Vcount(Vcount),    //Vertical Position
                        .R(Ra),
                        .G(Ga),
                        .B(Ba),
                        .Clk(Clk),          //Syaten Clock
                        .xReset(xReset) );  //Global Reset
                        
    Bar3  #( OrgX+Size*5,
             OrgX+Size*6,
             OrgY+Size/2,
             OrgY+Size*4+Size/2,
             BarFg,
             BarBg)
          SegB        ( .SW(Sb),
                        .Hcount(Hcount),    //Horizontal Position
                        .Vcount(Vcount),    //Vertical Position
                        .R(Rb),
                        .G(Gb),
                        .B(Bb),
                        .Clk(Clk),          //Syaten Clock
                        
                        .xReset(xReset) );  //Global Reset
    Bar3  #( OrgX+Size*5,
             OrgX+Size*6,
             OrgY+Size*4+Size/2,
             OrgY+Size*8+Size/2,
             BarFg,
             BarBg)
          SegC        ( .SW(Sc),
                        .Hcount(Hcount),    //Horizontal Position
                        .Vcount(Vcount),    //Vertical Position
                        .R(Rc),
                        .G(Gc),
                        .B(Bc),
                        .Clk(Clk),          //Syaten Clock
                        .xReset(xReset) );  //Global Reset
                        
    Bar3  #( OrgX+Size,
             OrgX+Size*5,
             OrgY+Size*8,
             OrgY+Size*9,
             BarFg,
             BarBg)
          SegD        ( .SW(Sd),
                        .Hcount(Hcount),    //Horizontal Position
                        .Vcount(Vcount),    //Vertical Position
                        .R(Rd),
                        .G(Gd),
                        .B(Bd),
                        .Clk(Clk),          //Syaten Clock
                        .xReset(xReset) );  //Global Reset
                        
    Bar3  #( OrgX,
             OrgX+Size,
             OrgY+Size*4+Size/2,
             OrgY+Size*8+Size/2,
             BarFg,
             BarBg)
          SegE        ( .SW(Se),
                        .Hcount(Hcount),    //Horizontal Position
                        .Vcount(Vcount),    //Vertical Position
                        .R(Re),
                        .G(Ge),
                        .B(Be),
                        .Clk(Clk),          //Syaten Clock
                        .xReset(xReset) );  //Global Reset
                        
    Bar3  #( OrgX,
             OrgX+Size,
             OrgY+Size/2,
             OrgY+Size*4+Size/2,
             BarFg,
             BarBg)
          SegF        ( .SW(Sf),
                        .Hcount(Hcount),    //Horizontal Position
                        .Vcount(Vcount),    //Vertical Position
                        .R(Rf),
                        .G(Gf),
                        .B(Bf),
                        .Clk(Clk),          //Syaten Clock
                        .xReset(xReset) );  //Global Reset
                        
    Bar3  #( OrgX+Size,
             OrgX+5*Size,
             OrgY+Size*4,
             OrgY+Size*5,
             BarFg,
             BarBg)
          SegG        ( .SW(Sg),
                        .Hcount(Hcount),    //Horizontal Position
                        .Vcount(Vcount),    //Vertical Position
                        .R(Rg),
                        .G(Gg),
                        .B(Bg),
                        .Clk(Clk),          //Syaten Clock
                        .xReset(xReset) );  //Global Reset

    Decode7Seg Decode7Seg( Din, {Sa, Sb, Sc, Sd, Se, Sf, Sg} ) ;
                    
    always @( posedge Clk or negedge xReset )
    begin
        if( xReset == 0 ) begin
            {R, G, B} <= BarBg ;
        end else begin
            R <= Ra | Rb | Rc | Rd | Re | Rf | Rg ;
            G <= Ga | Gb | Gc | Gd | Ge | Gf | Gg ;
            B <= Ba | Bb | Bc | Bd | Be | Bf | Bg ;            
        end
    end     
endmodule    