module ScoreDisp  (
                    DAin,       //Input 4Bit data
                    DBin,
                    DCin,
                    DDin,
                    LxR,
                    R,         //
                    G,         //
                    B,         //
                    Hsync,
                    Vsync,
                    Clk,       //Syaten Clock
                    xReset );  //Global Reset
    
    parameter       BarFg = 3'b111 ;
    parameter       BarBg = 3'b000 ;
    input     [3:0] DAin ;
    input     [3:0] DBin ;
    input     [3:0] DCin ;
    input     [3:0] DDin ;
    input           LxR ;
    output          R ;
    output          G ;
    output          B ;
    output          Hsync ;
    output          Vsync ;
    
    input           Clk ;
    input           xReset ;
    
    wire            Hsync ;
    wire            Vsync ;
    wire     [10:0] Hcount ;
    wire      [9:0] Vcount ;
    wire            Disp ;

    wire            R1, R2, R3, R4, Rcol1, Rcol2, Rul1, Rul2 ;
    wire            G1, G2, G3, G4, Gcol1, Gcol2, Gul1, Gul2 ;
    wire            B1, B2, B3, B4, Bcol1, Bcol2, Bul1, Bul2 ;
     
    reg             R, G, B ;
    
    Sync_Gen Sync_Gen ( .Hsync(Hsync),      //H-Sync
                        .Vsync(Vsync),      //V-Sync
                        .Hcount(Hcount),    //Horizontal Position
                        .Vcount(Vcount),    //Vertical Position
                        .Disp(Disp),        //Display Area
                        .Clk(Clk),          //Syaten Clock
                        .xReset(xReset) );  //Global Reset
    Bar3  #( 388,
             412,
             216,
             240,
             BarFg,
             BarBg)
          Col1        ( .SW(1'b1),
                        .Hcount(Hcount),    //Horizontal Position
                        .Vcount(Vcount),    //Vertical Position
                        .R(Rcol1),
                        .G(Gcol1),
                        .B(Bcol1),
                        .Clk(Clk),          //Syaten Clock
                        .xReset(xReset) );  //Global Reset
    Bar3  #( 388,
             412,
             312,
             336,
             BarFg,
             BarBg)
          Col2        ( .SW(1'b1),
                        .Hcount(Hcount),    //Horizontal Position
                        .Vcount(Vcount),    //Vertical Position
                        .R(Rcol2),
                        .G(Gcol2),
                        .B(Bcol2),
                        .Clk(Clk),          //Syaten Clock
                        .xReset(xReset) );  //Global Reset

    Bar3  #(  52,
             364,
             420,
             444,
             BarFg,
             BarBg)
          Ul1        ( .SW(LxR),
                        .Hcount(Hcount),    //Horizontal Position
                        .Vcount(Vcount),    //Vertical Position
                        .R(Rul1),
                        .G(Gul1),
                        .B(Bul1),
                        .Clk(Clk),          //Syaten Clock
                        .xReset(xReset) );  //Global Reset

    Bar3  #( 436,
             748,
             420,
             444,
             BarFg,
             BarBg)
          Ul2        ( .SW(~LxR),
                        .Hcount(Hcount),    //Horizontal Position
                        .Vcount(Vcount),    //Vertical Position
                        .R(Rul2),
                        .G(Gul2),
                        .B(Bul2),
                        .Clk(Clk),          //Syaten Clock
                        .xReset(xReset) );  //Global Reset                     

    Led7Seg #( 52,
              168,
               24,
             BarFg,
             BarBg)
          LED1     (  .Din(DAin),
                      .Hcount(Hcount),
                      .Vcount(Vcount),
                      .R(R1),
                      .G(G1),
                      .B(B1),
                      .Clk(Clk),
                      .xReset(xReset) );

    Led7Seg #( 220,168,
               24,
             BarFg,
             BarBg)
          LED2     (  .Din(DBin),
                      .Hcount(Hcount),
                      .Vcount(Vcount),
                      .R(R2),
                      .G(G2),
                      .B(B2),
                      .Clk(Clk),
                      .xReset(xReset) );

    Led7Seg #( 436,168,
               24,
             BarFg,
             BarBg)
          LED3     (  .Din(DCin),
                      .Hcount(Hcount),
                      .Vcount(Vcount),
                      .R(R3),
                      .G(G3),
                      .B(B3),
                      .Clk(Clk),
                      .xReset(xReset) );                      

    Led7Seg #( 604,168,
               24,
             BarFg,
             BarBg)
          LED4     (  .Din(DDin),
                      .Hcount(Hcount),
                      .Vcount(Vcount),
                      .R(R4),
                      .G(G4),
                      .B(B4),
                      .Clk(Clk),
                      .xReset(xReset) );
                                          
    always @( posedge Clk or negedge xReset )
    begin
        if( xReset == 0 ) begin
            {R, G, B} <= BarBg ;
        end else begin
            R <= R1 | R2 | R3 | R4 | Rcol1 | Rcol2 | Rul1 | Rul2 ;
            G <= G1 | G2 | G3 | G4 | Gcol1 | Gcol2 | Gul1 | Gul2 ;
            B <= B1 | B2 | B3 | B4 | Bcol1 | Bcol2 | Bul1 | Bul2 | ((Hcount==799) & (Vcount ==0 ))
            ;
        end
    end     
endmodule    